@@ -61,14 +61,14 @@ def fix_config_vars(names, values):
         if 'ARCHFLAGS' in os.environ:
             ARCHFLAGS = os.environ['ARCHFLAGS']
             for i, flag in enumerate(list(values)):
-                flag, count = re.subn('-arch\s+\w+', ' ', flag)
+                flag, count = re.subn('-arch\s+\w+', ' ', str(flag))
                 if count and ARCHFLAGS:
                     flag = flag + ' ' + ARCHFLAGS
                 values[i] = flag
         if 'SDKROOT' in os.environ:
             SDKROOT = os.environ['SDKROOT']
             for i, flag in enumerate(list(values)):
-                flag, count = re.subn('-isysroot [^ \t]*', ' ', flag)
+                flag, count = re.subn('-isysroot [^ \t]*', ' ', str(flag))
                 if count and SDKROOT:
                     flag = flag + ' ' + '-isysroot ' + SDKROOT
                 values[i] = flag
@@ -130,7 +130,6 @@ class PetscConfig:
             'major'  : re.compile(r"#define\s+PETSC_VERSION_MAJOR\s+(\d+)"),
             'minor'  : re.compile(r"#define\s+PETSC_VERSION_MINOR\s+(\d+)"),
             'micro'  : re.compile(r"#define\s+PETSC_VERSION_SUBMINOR\s+(\d+)"),
-            'patch'  : re.compile(r"#define\s+PETSC_VERSION_PATCH\s+(\d+)"),
             'release': re.compile(r"#define\s+PETSC_VERSION_RELEASE\s+(-*\d+)"),
             }
         petscversion_h = os.path.join(petsc_dir, 'include', 'petscversion.h')
@@ -228,8 +227,19 @@ class PetscConfig:
         ldshared = str.join(' ', ldshared)
         #
         def get_flags(cmd):
-            try: return ' '.join(split_quoted(cmd)[1:])
-            except: return ''
+            if not cmd: return ''
+            cmd = split_quoted(cmd)
+            if os.path.basename(cmd[0]) == 'xcrun':
+                del cmd[0]
+                while True:
+                    if cmd[0] == '-sdk':
+                        del cmd[0:2]
+                        continue
+                    if cmd[0] == '-log':
+                        del cmd[0]
+                        continue
+                    break
+            return ' '.join(cmd[1:])
         # PETSc C compiler
         PCC = self['PCC']
         PCC_FLAGS = get_flags(cc) + ' ' + self['PCC_FLAGS']
