@@ -24,17 +24,9 @@ PetscErrorCode FormInitGuess(DM da, Vec X, Params *p)
   PetscInt       i,j,k,Mx,My,Mz,xs,ys,zs,xm,ym,zm;
   PetscReal      lambda,temp1,hx,hy,hz,tempk,tempj;
   PetscScalar    ***x;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-
-  ierr = DMDAGetInfo(da,PETSC_IGNORE,
-                     &Mx,&My,&Mz,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE);
-
+  PetscCall(DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,&Mz,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE));
   lambda = p->lambda_;
   hx     = 1.0/(PetscReal)(Mx-1);
   hy     = 1.0/(PetscReal)(My-1);
@@ -51,7 +43,7 @@ PetscErrorCode FormInitGuess(DM da, Vec X, Params *p)
     - You MUST call VecRestoreArray() when you no longer need access
       to the array.
   */
-  ierr = DMDAVecGetArray(da,X,&x);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArray(da,X,&x));
 
   /*
     Get local grid boundaries (for 3-dimensional DMDA):
@@ -60,7 +52,7 @@ PetscErrorCode FormInitGuess(DM da, Vec X, Params *p)
 
     - xm, ym, zm: widths of local grid (no ghost points)
   */
-  ierr = DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm));
 
   /*
     Compute initial guess over the locally owned part of the grid
@@ -83,29 +75,20 @@ PetscErrorCode FormInitGuess(DM da, Vec X, Params *p)
   /*
     Restore vector
   */
-  ierr = DMDAVecRestoreArray(da,X,&x);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(da,X,&x));
 
   PetscFunctionReturn(0);
 }
 
-
 PetscErrorCode FormFunction(DM da, Vec X, Vec F, Params *p)
 {
   PetscInt       i,j,k,Mx,My,Mz,xs,ys,zs,xm,ym,zm;
   PetscReal      two = 2.0,lambda,hx,hy,hz,hxhzdhy,hyhzdhx,hxhydhz,sc;
   PetscScalar    u_north,u_south,u_east,u_west,u_up,u_down,u,u_xx,u_yy,u_zz,***x,***f;
   Vec            localX;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-
-  ierr = DMDAGetInfo(da,PETSC_IGNORE,
-                     &Mx,&My,&Mz,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE);
-
+  PetscCall(DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,&Mz,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE));
   lambda = p->lambda_;
   hx     = 1.0/(PetscReal)(Mx-1);
   hy     = 1.0/(PetscReal)(My-1);
@@ -115,7 +98,7 @@ PetscErrorCode FormFunction(DM da, Vec X, Vec F, Params *p)
   hyhzdhx = hy*hz/hx;
   hxhydhz = hx*hy/hz;
 
-  ierr = DMGetLocalVector(da,&localX);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da,&localX));
 
   /*
     Scatter ghost points to local vector,using the 2-step process
@@ -123,19 +106,19 @@ PetscErrorCode FormFunction(DM da, Vec X, Vec F, Params *p)
     between these two statements, computations can be done while
     messages are in transition.
   */
-  ierr = DMGlobalToLocalBegin(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
-  ierr = DMGlobalToLocalEnd(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
+  PetscCall(DMGlobalToLocalBegin(da,X,INSERT_VALUES,localX));
+  PetscCall(DMGlobalToLocalEnd(da,X,INSERT_VALUES,localX));
 
   /*
     Get pointers to vector data.
   */
-  ierr = DMDAVecGetArray(da,localX,&x);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,F,&f);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArray(da,localX,&x));
+  PetscCall(DMDAVecGetArray(da,F,&f));
 
   /*
     Get local grid boundaries.
   */
-  ierr = DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm));
 
   /*
     Compute function over the locally owned part of the grid.
@@ -167,15 +150,14 @@ PetscErrorCode FormFunction(DM da, Vec X, Vec F, Params *p)
   /*
     Restore vectors.
   */
-  ierr = DMDAVecRestoreArray(da,F,&f);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,localX,&x);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&localX);CHKERRQ(ierr);
-  ierr = PetscLogFlops(11.0*ym*xm);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(da,F,&f));
+  PetscCall(DMDAVecRestoreArray(da,localX,&x));
+  PetscCall(DMRestoreLocalVector(da,&localX));
+  PetscCall(PetscLogFlops(11.0*ym*xm));
 
   PetscFunctionReturn(0);
 }
 
-
 PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
 {
   PetscInt       i,j,k,Mx,My,Mz,xs,ys,zs,xm,ym,zm;
@@ -183,17 +165,9 @@ PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
   PetscScalar    v[7],***x;
   MatStencil     col[7],row;
   Vec            localX;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
-
-  ierr = DMDAGetInfo(da,PETSC_IGNORE,
-                     &Mx,&My,&Mz,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,
-                     PETSC_IGNORE);
-
+  PetscCall(DMDAGetInfo(da,PETSC_IGNORE,&Mx,&My,&Mz,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE,PETSC_IGNORE));
   lambda = p->lambda_;
   hx     = 1.0/(PetscReal)(Mx-1);
   hy     = 1.0/(PetscReal)(My-1);
@@ -203,7 +177,7 @@ PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
   hyhzdhx = hy*hz/hx;
   hxhydhz = hx*hy/hz;
 
-  ierr = DMGetLocalVector(da,&localX);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da,&localX));
 
   /*
     Scatter ghost points to local vector, using the 2-step process
@@ -211,18 +185,18 @@ PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
     between these two statements, computations can be done while
     messages are in transition.
   */
-  ierr = DMGlobalToLocalBegin(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
-  ierr = DMGlobalToLocalEnd(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
+  PetscCall(DMGlobalToLocalBegin(da,X,INSERT_VALUES,localX));
+  PetscCall(DMGlobalToLocalEnd(da,X,INSERT_VALUES,localX));
 
   /*
     Get pointer to vector data.
   */
-  ierr = DMDAVecGetArray(da,localX,&x);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArray(da,localX,&x));
 
   /*
     Get local grid boundaries.
   */
-  ierr = DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da,&xs,&ys,&zs,&xm,&ym,&zm));
 
   /*
     Compute entries for the locally owned part of the Jacobian.
@@ -246,7 +220,7 @@ PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
         /* boundary points */
         if (i == 0 || j == 0 || k == 0|| i == Mx-1 || j == My-1 || k == Mz-1) {
           v[0] = 1.0;
-          ierr = MatSetValuesStencil(J,1,&row,1,&row,v,INSERT_VALUES);CHKERRQ(ierr);
+          PetscCall(MatSetValuesStencil(J,1,&row,1,&row,v,INSERT_VALUES));
         } else {
         /* interior grid points */
           v[0] = -hxhydhz; col[0].k=k-1;col[0].j=j;  col[0].i = i;
@@ -256,26 +230,26 @@ PetscErrorCode FormJacobian(DM da, Vec X, Mat J, Params *p)
           v[4] = -hyhzdhx; col[4].k=k;  col[4].j=j;  col[4].i = i+1;
           v[5] = -hxhzdhy; col[5].k=k;  col[5].j=j+1;col[5].i = i;
           v[6] = -hxhydhz; col[6].k=k+1;col[6].j=j;  col[6].i = i;
-          ierr = MatSetValuesStencil(J,1,&row,7,col,v,INSERT_VALUES);CHKERRQ(ierr);
+          PetscCall(MatSetValuesStencil(J,1,&row,7,col,v,INSERT_VALUES));
         }
       }
     }
   }
-  ierr = DMDAVecRestoreArray(da,localX,&x);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&localX);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(da,localX,&x));
+  PetscCall(DMRestoreLocalVector(da,&localX));
 
   /*
     Assemble matrix, using the 2-step process: MatAssemblyBegin(),
     MatAssemblyEnd().
   */
-  ierr = MatAssemblyBegin(J,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(J,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(J,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(J,MAT_FINAL_ASSEMBLY));
 
   /*
     Tell the matrix we will never add a new nonzero location to the
     matrix. If we do, it will generate an error.
   */
-  ierr = MatSetOption(J,MAT_NEW_NONZERO_LOCATION_ERR,PETSC_TRUE);CHKERRQ(ierr);
+  PetscCall(MatSetOption(J,MAT_NEW_NONZERO_LOCATION_ERR,PETSC_TRUE));
 
   PetscFunctionReturn(0);
 }
