@@ -35,10 +35,10 @@ static PetscStageLog petsc_stageLog = NULL;
 static PetscErrorCode
 PetscLogStageFindId(const char name[], PetscLogStage *stageid)
 {
-  int            s;
-  PetscStageLog  stageLog = 0;
-  PetscBool      match = PETSC_FALSE;
-  PetscErrorCode ierr;
+  int           s;
+  PetscStageLog stageLog = 0;
+  PetscBool     match    = PETSC_FALSE;
+
   PetscFunctionBegin;
   PetscValidCharPointer(name,1);
   PetscValidIntPointer(stageid,2);
@@ -46,7 +46,7 @@ PetscLogStageFindId(const char name[], PetscLogStage *stageid)
   if (!(stageLog=petsc_stageLog)) PetscFunctionReturn(0); /* logging is off ? */
   for (s = 0; s < stageLog->numStages; s++) {
     const char *sname = stageLog->stageInfo[s].name;
-    ierr = PetscStrcasecmp(sname, name, &match);CHKERRQ(ierr);
+    PetscCall(PetscStrcasecmp(sname, name, &match));
     if (match) { *stageid = s; break; }
   }
   PetscFunctionReturn(0);
@@ -55,10 +55,10 @@ PetscLogStageFindId(const char name[], PetscLogStage *stageid)
 static PetscErrorCode
 PetscLogClassFindId(const char name[], PetscClassId *classid)
 {
-  int            c;
-  PetscStageLog  stageLog = 0;
-  PetscBool      match = PETSC_FALSE;
-  PetscErrorCode ierr;
+  int           c;
+  PetscStageLog stageLog = 0;
+  PetscBool     match    = PETSC_FALSE;
+
   PetscFunctionBegin;
   PetscValidCharPointer(name,1);
   PetscValidIntPointer(classid,2);
@@ -67,7 +67,7 @@ PetscLogClassFindId(const char name[], PetscClassId *classid)
   for (c = 0; c < stageLog->classLog->numClasses; c++) {
     const char *cname = stageLog->classLog->classInfo[c].name;
     PetscClassId id = PetscCLASSID(stageLog,c);
-    ierr = PetscStrcasecmp(cname, name, &match);CHKERRQ(ierr);
+    PetscCall(PetscStrcasecmp(cname, name, &match));
     if (match) { *classid = id; break; }
   }
   PetscFunctionReturn(0);
@@ -76,10 +76,10 @@ PetscLogClassFindId(const char name[], PetscClassId *classid)
 static PetscErrorCode
 PetscLogEventFindId(const char name[], PetscLogEvent *eventid)
 {
-  int            e;
-  PetscStageLog  stageLog = 0;
-  PetscBool      match = PETSC_FALSE;
-  PetscErrorCode ierr;
+  int           e;
+  PetscStageLog stageLog = 0;
+  PetscBool     match    = PETSC_FALSE;
+
   PetscFunctionBegin;
   PetscValidCharPointer(name,1);
   PetscValidIntPointer(eventid,2);
@@ -87,7 +87,7 @@ PetscLogEventFindId(const char name[], PetscLogEvent *eventid)
   if (!(stageLog=petsc_stageLog)) PetscFunctionReturn(0); /* logging is off ? */
   for (e = 0; e < stageLog->eventLog->numEvents; e++) {
     const char *ename = stageLog->eventLog->eventInfo[e].name;
-    ierr = PetscStrcasecmp(ename, name, &match);CHKERRQ(ierr);
+    PetscCall(PetscStrcasecmp(ename, name, &match));
     if (match) { *eventid = e; break; }
   }
   PetscFunctionReturn(0);
@@ -142,53 +142,58 @@ PetscLogEventFindName(PetscLogEvent eventid,
   PetscFunctionReturn(0);
 }
 
-#if !defined(PETSC_USE_LOG)
-#undef PetscLogEventGetPerfInfo
+/* ---------------------------------------------------------------- */
+
+/* The object is not used so far. I expect PETSc will sooner or later support
+   a different device context for each object */
 static PetscErrorCode
-PetscLogEventGetPerfInfo(int stage,PetscLogEvent event,PetscEventPerfInfo *info)
+PetscObjectGetDeviceId(PetscObject o, PetscInt *id)
 {
-  PetscErrorCode ierr;
+#if defined(PETSC_HAVE_DEVICE)
+  PetscDeviceContext dctx;
+  PetscDevice device;
+#endif
   PetscFunctionBegin;
-  PetscValidPointer(info,3);
-  (void)stage; (void)event; /* unused */
-  ierr = PetscMemzero(info,sizeof(PetscEventPerfInfo));CHKERRQ(ierr);
+  PetscValidHeader(o,1);
+#if defined(PETSC_HAVE_DEVICE)
+  PetscCall(PetscDeviceContextGetCurrentContext(&dctx));
+  PetscCall(PetscDeviceContextGetDevice(dctx,&device));
+  PetscCall(PetscDeviceGetDeviceId(device,id));
+#else
+  *id = 0;
+#endif
   PetscFunctionReturn(0);
 }
-#endif
 
 /* ---------------------------------------------------------------- */
 
-PETSC_STATIC_INLINE PetscErrorCode
-VecStrideSum(Vec v, PetscInt start, PetscScalar *a)
+static inline PetscErrorCode
+VecGetCurrentMemType(Vec v, PetscMemType *m)
 {
-  PetscInt          i,n,bs;
-  const PetscScalar *x;
-  PetscScalar       sum;
-  MPI_Comm          comm;
-  PetscErrorCode    ierr;
+  PetscBool bound;
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v,VEC_CLASSID,1);
-  PetscValidType(v,1);
-  PetscValidScalarPointer(a,2);
-  ierr = VecGetBlockSize(v,&bs);CHKERRQ(ierr);
-  if (start <  0)  SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                            "Negative start %D",start);
-  if (start >= bs) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,
-                            "Start of stride subvector (%D) is too large "
-                            "for block size (%D)",start,bs);
-  ierr = VecGetLocalSize(v,&n);CHKERRQ(ierr);
-  ierr = VecGetArrayRead(v,&x);CHKERRQ(ierr);
-  sum = (PetscScalar)0.0;
-  for (i=start; i<n; i+=bs) sum += x[i];
-  ierr = VecRestoreArrayRead(v,&x);CHKERRQ(ierr);
-  ierr = PetscObjectGetComm((PetscObject)v,&comm);CHKERRQ(ierr);
-  ierr = MPI_Allreduce(&sum,a,1,MPIU_SCALAR,MPIU_SUM,comm);CHKERRMPI(ierr);
+  PetscValidPointer(m,2);
+  *m = PETSC_MEMTYPE_HOST;
+  PetscCall(VecBoundToCPU(v,&bound));
+  if (!bound) {
+    VecType rtype;
+    char *iscuda, *iship, *iskok;
+
+    PetscCall(VecGetRootType_Private(v,&rtype));
+    PetscCall(PetscStrstr(rtype,"cuda",&iscuda));
+    PetscCall(PetscStrstr(rtype,"hip",&iship));
+    PetscCall(PetscStrstr(rtype,"kokkos",&iskok));
+    if (iscuda)     *m = PETSC_MEMTYPE_CUDA;
+    else if (iship) *m = PETSC_MEMTYPE_HIP;
+    else if (iskok) *m = PETSC_MEMTYPE_KOKKOS;
+  }
   PetscFunctionReturn(0);
 }
 
 /* ---------------------------------------------------------------- */
 
-PETSC_STATIC_INLINE
+static inline
 PetscErrorCode MatIsPreallocated(Mat A,PetscBool *flag)
 {
   PetscFunctionBegin;
@@ -198,31 +203,58 @@ PetscErrorCode MatIsPreallocated(Mat A,PetscBool *flag)
   PetscFunctionReturn(0);
 }
 
-PETSC_STATIC_INLINE
-PetscErrorCode MatHasPreallocationAIJ(Mat A,PetscBool *aij,PetscBool *baij,PetscBool *sbaij)
+static inline
+PetscErrorCode MatHasPreallocationAIJ(Mat A,PetscBool *aij,PetscBool *baij,PetscBool *sbaij,PetscBool *is)
 {
   void (*f)(void) = 0;
-  PetscErrorCode ierr;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A,MAT_CLASSID,1);
   PetscValidType(A,1);
   PetscValidPointer(aij,2);
   PetscValidPointer(baij,3);
   PetscValidPointer(sbaij,4);
-  *aij = *baij = *sbaij = PETSC_FALSE;
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatMPIAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatSeqAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
+  PetscValidPointer(is,5);
+  *aij = *baij = *sbaij = *is = PETSC_FALSE;
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatMPIAIJSetPreallocation_C",&f));
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatSeqAIJSetPreallocation_C",&f));
   if (f)  {*aij = PETSC_TRUE; goto done;};
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatMPIBAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatSeqBAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatMPIBAIJSetPreallocation_C",&f));
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatSeqBAIJSetPreallocation_C",&f));
   if (f)  {*baij = PETSC_TRUE; goto done;};
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatMPISBAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
-  if (!f) {ierr = PetscObjectQueryFunction((PetscObject)A,"MatSeqSBAIJSetPreallocation_C",&f);CHKERRQ(ierr);}
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatMPISBAIJSetPreallocation_C",&f));
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatSeqSBAIJSetPreallocation_C",&f));
   if (f)  {*sbaij = PETSC_TRUE; goto done;};
+  if (!f) PetscCall(PetscObjectQueryFunction((PetscObject)A,"MatISSetPreallocation_C",&f));
+  if (f)  {*is = PETSC_TRUE; goto done;};
  done:
   PetscFunctionReturn(0);
 }
 
+static inline PetscErrorCode
+MatGetCurrentMemType(Mat A, PetscMemType *m)
+{
+  PetscBool bound;
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(A,MAT_CLASSID,1);
+  PetscValidPointer(m,2);
+  *m = PETSC_MEMTYPE_HOST;
+  PetscCall(MatBoundToCPU(A,&bound));
+  if (!bound) {
+    VecType rtype;
+    char *iscuda, *iship, *iskok;
+
+    PetscCall(MatGetRootType_Private(A,&rtype));
+    PetscCall(PetscStrstr(rtype,"cuda",&iscuda));
+    PetscCall(PetscStrstr(rtype,"hip",&iship));
+    PetscCall(PetscStrstr(rtype,"kokkos",&iskok));
+    if (iscuda)     *m = PETSC_MEMTYPE_CUDA;
+    else if (iship) *m = PETSC_MEMTYPE_HIP;
+    else if (iskok) *m = PETSC_MEMTYPE_KOKKOS;
+  }
+  PetscFunctionReturn(0);
+}
+
 #ifndef MatNullSpaceFunction
 typedef PetscErrorCode MatNullSpaceFunction(MatNullSpace,Vec,void*);
 #endif
@@ -233,10 +265,9 @@ static PetscErrorCode
 MatFactorInfoDefaults(PetscBool incomplete,PetscBool cholesky,
                       MatFactorInfo *info)
 {
-  PetscErrorCode ierr;
   PetscFunctionBegin;
   PetscValidPointer(info,2);
-  ierr = MatFactorInfoInitialize(info);CHKERRQ(ierr);
+  PetscCall(MatFactorInfoInitialize(info));
   if (incomplete) {
     info->levels         = (PetscReal)0;
     info->diagonal_fill  = (PetscReal)0;
@@ -273,8 +304,7 @@ KSPSetIterationNumber(KSP ksp, PetscInt its)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  if (its < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                       "iteration number must be nonnegative");
+  PetscCheck(its >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"iteration number must be nonnegative");
   ksp->its = its;
   PetscFunctionReturn(0);
 }
@@ -284,8 +314,7 @@ KSPSetResidualNorm(KSP ksp, PetscReal rnorm)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
-  if (rnorm < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "residual norm must be nonnegative");
+  PetscCheck(rnorm >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"residual norm must be nonnegative");
   ksp->rnorm = rnorm;
   PetscFunctionReturn(0);
 }
@@ -293,15 +322,12 @@ KSPSetResidualNorm(KSP ksp, PetscReal rnorm)
 static PetscErrorCode
 KSPConvergenceTestCall(KSP ksp, PetscInt its, PetscReal rnorm, KSPConvergedReason *reason)
 {
-  PetscErrorCode ierr;
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,1);
   PetscValidPointer(reason,4);
-  if (its < 0)   SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "iteration number must be nonnegative");
-  if (rnorm < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "residual norm must be nonnegative");
-  ierr = (*ksp->converged)(ksp,its,rnorm,reason,ksp->cnvP);CHKERRQ(ierr);
+  PetscCheck(its >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"iteration number must be nonnegative");
+  PetscCheck(rnorm >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"residual norm must be nonnegative");
+  PetscCall((*ksp->converged)(ksp,its,rnorm,reason,ksp->cnvP));
   PetscFunctionReturn(0);
 }
 
@@ -321,19 +347,14 @@ SNESConvergenceTestCall(SNES snes, PetscInt its,
                         PetscReal xnorm, PetscReal ynorm, PetscReal fnorm,
                         SNESConvergedReason *reason)
 {
-  PetscErrorCode ierr;
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
   PetscValidPointer(reason,4);
-  if (its < 0)   SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "iteration number must be nonnegative");
-  if (xnorm < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "solution norm must be nonnegative");
-  if (ynorm < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "step norm must be nonnegative");
-  if (fnorm < 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,
-                         "function norm must be nonnegative");
-  ierr = (*snes->ops->converged)(snes,its,xnorm,ynorm,fnorm,reason,snes->cnvP);CHKERRQ(ierr);
+  PetscCheck(its >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"iteration number must be nonnegative");
+  PetscCheck(xnorm >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"solution norm must be nonnegative");
+  PetscCheck(ynorm >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"step norm must be nonnegative");
+  PetscCheck(fnorm >= 0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"function norm must be nonnegative");
+  PetscUseTypeMethod(snes,converged ,its,xnorm,ynorm,fnorm,reason,snes->cnvP);
   PetscFunctionReturn(0);
 }
 
@@ -342,13 +363,13 @@ SNESGetUseMFFD(SNES snes,PetscBool *flag)
 {
   PetscErrorCode (*jac)(SNES,Vec,Mat,Mat,void*) = PETSC_NULL;
   Mat            J = PETSC_NULL;
-  PetscErrorCode ierr;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
   PetscValidPointer(flag,2);
   *flag = PETSC_FALSE;
-  ierr = SNESGetJacobian(snes,&J,0,&jac,0);CHKERRQ(ierr);
-  if (J) { ierr = PetscObjectTypeCompare((PetscObject)J,MATMFFD,flag);CHKERRQ(ierr); }
+  PetscCall(SNESGetJacobian(snes,&J,0,&jac,0));
+  if (J) PetscCall(PetscObjectTypeCompare((PetscObject)J,MATMFFD,flag));
   else if (jac == MatMFFDComputeJacobian) *flag = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
@@ -356,18 +377,17 @@ SNESGetUseMFFD(SNES snes,PetscBool *flag)
 static PetscErrorCode
 SNESSetUseMFFD(SNES snes,PetscBool flag)
 {
-  const char*    prefix = PETSC_NULL;
-  PetscBool      flg = PETSC_FALSE;
-  Vec            r = PETSC_NULL;
-  Mat            A = PETSC_NULL,B = PETSC_NULL,J = PETSC_NULL;
-  void*          funP = PETSC_NULL;
-  void*          jacP = PETSC_NULL;
-  PetscErrorCode ierr;
+  const char* prefix = PETSC_NULL;
+  PetscBool   flg    = PETSC_FALSE;
+  Vec         r      = PETSC_NULL;
+  Mat         A      = PETSC_NULL,B = PETSC_NULL,J = PETSC_NULL;
+  void*       funP   = PETSC_NULL;
+  void*       jacP   = PETSC_NULL;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
 
-  ierr = SNESGetUseMFFD(snes,&flg);CHKERRQ(ierr);
+  PetscCall(SNESGetUseMFFD(snes,&flg));
   if (flg  &&  flag) PetscFunctionReturn(0);
   if (!flg && !flag) PetscFunctionReturn(0);
   if (flg  && !flag) {
@@ -376,30 +396,28 @@ SNESSetUseMFFD(SNES snes,PetscBool flag)
     PetscFunctionReturn(PETSC_ERR_ARG_WRONGSTATE);
   }
 
-  ierr = SNESGetOptionsPrefix(snes,&prefix);CHKERRQ(ierr);
-  ierr = SNESGetFunction(snes,&r,0,&funP);CHKERRQ(ierr);
-  ierr = SNESGetJacobian(snes,&A,&B,0,&jacP);CHKERRQ(ierr);
+  PetscCall(SNESGetOptionsPrefix(snes,&prefix));
+  PetscCall(SNESGetFunction(snes,&r,0,&funP));
+  PetscCall(SNESGetJacobian(snes,&A,&B,0,&jacP));
   if (!r) {
     SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONGSTATE,"SNESSetFunction() must be called first");
     PetscFunctionReturn(PETSC_ERR_ARG_WRONGSTATE);
   }
-  ierr = MatCreateSNESMF(snes,&J);CHKERRQ(ierr);
-  ierr = MatSetOptionsPrefix(J,prefix);CHKERRQ(ierr);
-  ierr = MatSetFromOptions(J);CHKERRQ(ierr);
+  PetscCall(MatCreateSNESMF(snes,&J));
+  PetscCall(MatSetOptionsPrefix(J,prefix));
+  PetscCall(MatSetFromOptions(J));
   if (!B) {
     KSP       ksp;
     PC        pc;
     PetscBool shell,python;
-    ierr = SNESSetJacobian(snes,J,J,MatMFFDComputeJacobian,jacP);CHKERRQ(ierr);
-    ierr = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
-    ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
-    ierr = PetscObjectTypeCompare((PetscObject)pc,PCSHELL,&shell);CHKERRQ(ierr);
-    ierr = PetscObjectTypeCompare((PetscObject)pc,PCPYTHON,&python);CHKERRQ(ierr);
-    if (!shell && !python) { ierr = PCSetType(pc,PCNONE);CHKERRQ(ierr); }
-  } else {
-    ierr = SNESSetJacobian(snes,J,0,0,0);CHKERRQ(ierr);
-  }
-  ierr = MatDestroy(&J);CHKERRQ(ierr);
+    PetscCall(SNESSetJacobian(snes,J,J,MatMFFDComputeJacobian,jacP));
+    PetscCall(SNESGetKSP(snes,&ksp));
+    PetscCall(KSPGetPC(ksp,&pc));
+    PetscCall(PetscObjectTypeCompare((PetscObject)pc,PCSHELL,&shell));
+    PetscCall(PetscObjectTypeCompare((PetscObject)pc,PCPYTHON,&python));
+    if (!shell && !python) PetscCall(PCSetType(pc,PCNONE));
+  } else PetscCall(SNESSetJacobian(snes,J,0,0,0));
+  PetscCall(MatDestroy(&J));
 
   PetscFunctionReturn(0);
 }
@@ -408,12 +426,12 @@ static PetscErrorCode
 SNESGetUseFDColoring(SNES snes,PetscBool *flag)
 {
   PetscErrorCode (*jac)(SNES,Vec,Mat,Mat,void*) = PETSC_NULL;
-  PetscErrorCode ierr;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
   PetscValidPointer(flag,2);
   *flag = PETSC_FALSE;
-  ierr = SNESGetJacobian(snes,0,0,&jac,0);CHKERRQ(ierr);
+  PetscCall(SNESGetJacobian(snes,0,0,&jac,0));
   if (jac == SNESComputeJacobianDefaultColor) *flag = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
@@ -427,28 +445,28 @@ SNESSetUseFDColoring(SNES snes,PetscBool flag)
   Mat            A = PETSC_NULL,B = PETSC_NULL;
   PetscErrorCode (*jac)(SNES,Vec,Mat,Mat,void*) = PETSC_NULL;
   void*          jacP = PETSC_NULL;
-  PetscErrorCode ierr;
+
   PetscFunctionBegin;
   PetscValidHeaderSpecific(snes,SNES_CLASSID,1);
 
-  ierr = SNESGetUseFDColoring(snes,&flg);CHKERRQ(ierr);
+  PetscCall(SNESGetUseFDColoring(snes,&flg));
   if (flg  &&  flag) PetscFunctionReturn(0);
   if (!flg && !flag) PetscFunctionReturn(0);
   if (flg  && !flag) {
     SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONGSTATE,
-            "cannot change colored finite diferences once it is set");
+            "cannot change colored finite differences once it is set");
     PetscFunctionReturn(PETSC_ERR_ARG_WRONGSTATE);
   }
 
-  ierr = SNESGetFunction(snes,NULL,&fun,&funP);CHKERRQ(ierr);
-  ierr = SNESGetJacobian(snes,&A,&B,&jac,&jacP);CHKERRQ(ierr);
-  ierr = SNESSetJacobian(snes,A,B,SNESComputeJacobianDefaultColor,0);CHKERRQ(ierr);
+  PetscCall(SNESGetFunction(snes,NULL,&fun,&funP));
+  PetscCall(SNESGetJacobian(snes,&A,&B,&jac,&jacP));
+  PetscCall(SNESSetJacobian(snes,A,B,SNESComputeJacobianDefaultColor,0));
   {
     DM     dm;
     DMSNES sdm;
-    ierr = SNESGetDM(snes,&dm);CHKERRQ(ierr);
-    ierr = DMGetDMSNES(dm,&sdm);CHKERRQ(ierr);
-    sdm->jacobianctx = NULL;
+    PetscCall(SNESGetDM(snes,&dm));
+    PetscCall(DMGetDMSNES(dm,&sdm));
+    PetscCall(DMSNESUnsetJacobianContext_Internal(dm));
   }
   PetscFunctionReturn(0);
 }
@@ -465,19 +483,19 @@ DMDACreateND(MPI_Comm comm,
              DMDAStencilType stencil_type,PetscInt stencil_width,
              DM *dm)
 {
-  DM             da;
-  PetscErrorCode ierr;
+  DM da;
+
   PetscFunctionBegin;
   PetscValidPointer(dm,18);
-  ierr = DMDACreate(comm,&da);CHKERRQ(ierr);
-  ierr = DMSetDimension(da,dim);CHKERRQ(ierr);
-  ierr = DMDASetDof(da,dof);CHKERRQ(ierr);
-  ierr = DMDASetSizes(da,M,N,P);CHKERRQ(ierr);
-  ierr = DMDASetNumProcs(da,m,n,p);CHKERRQ(ierr);
-  ierr = DMDASetOwnershipRanges(da,lx,ly,lz);CHKERRQ(ierr);
-  ierr = DMDASetBoundaryType(da,bx,by,bz);CHKERRQ(ierr);
-  ierr = DMDASetStencilType(da,stencil_type);CHKERRQ(ierr);
-  ierr = DMDASetStencilWidth(da,stencil_width);CHKERRQ(ierr);
+  PetscCall(DMDACreate(comm,&da));
+  PetscCall(DMSetDimension(da,dim));
+  PetscCall(DMDASetDof(da,dof));
+  PetscCall(DMDASetSizes(da,M,N,P));
+  PetscCall(DMDASetNumProcs(da,m,n,p));
+  PetscCall(DMDASetOwnershipRanges(da,lx,ly,lz));
+  PetscCall(DMDASetBoundaryType(da,bx,by,bz));
+  PetscCall(DMDASetStencilType(da,stencil_type));
+  PetscCall(DMDASetStencilWidth(da,stencil_width));
   *dm = (DM)da;
   PetscFunctionReturn(0);
 }
