@@ -7,7 +7,7 @@ import numpy as np
 
 # --------------------------------------------------------------------
 
-ERR_SUP = 56
+ERR_ARG_OUTOFRANGE = 63
 
 class BaseTestPlex(object):
 
@@ -27,6 +27,7 @@ class BaseTestPlex(object):
     def tearDown(self):
         self.plex.destroy()
         self.plex = None
+        PETSc.garbage_cleanup()
 
     def testTopology(self):
         rank = self.COMM.rank
@@ -130,20 +131,80 @@ class BaseTestPlex(object):
         self.assertNotEqual(numInterior, pEnd - pStart)
         self.assertEqual(numBoundary + numInterior, pEnd - pStart)
 
+    def testMetric(self):
+        if self.DIM == 1: return
+        self.plex.distribute()
+        if self.CELLS is None and not self.plex.isSimplex(): return
+        self.plex.orient()
+
+        h_min = 1.0e-30
+        h_max = 1.0e+30
+        a_max = 1.0e+10
+        target = 8.0
+        p = 1.0
+        beta = 1.3
+        hausd = 0.01
+        self.plex.metricSetUniform(False)
+        self.plex.metricSetIsotropic(False)
+        self.plex.metricSetRestrictAnisotropyFirst(False)
+        self.plex.metricSetNoInsertion(False)
+        self.plex.metricSetNoSwapping(False)
+        self.plex.metricSetNoMovement(False)
+        self.plex.metricSetNoSurf(False)
+        self.plex.metricSetVerbosity(-1)
+        self.plex.metricSetNumIterations(3)
+        self.plex.metricSetMinimumMagnitude(h_min)
+        self.plex.metricSetMaximumMagnitude(h_max)
+        self.plex.metricSetMaximumAnisotropy(a_max)
+        self.plex.metricSetTargetComplexity(target)
+        self.plex.metricSetNormalizationOrder(p)
+        self.plex.metricSetGradationFactor(beta)
+        self.plex.metricSetHausdorffNumber(hausd)
+
+        self.assertFalse(self.plex.metricIsUniform())
+        self.assertFalse(self.plex.metricIsIsotropic())
+        self.assertFalse(self.plex.metricRestrictAnisotropyFirst())
+        self.assertFalse(self.plex.metricNoInsertion())
+        self.assertFalse(self.plex.metricNoSwapping())
+        self.assertFalse(self.plex.metricNoMovement())
+        self.assertFalse(self.plex.metricNoSurf())
+        assert self.plex.metricGetVerbosity() == -1
+        assert self.plex.metricGetNumIterations() == 3
+        assert np.isclose(self.plex.metricGetMinimumMagnitude(), h_min)
+        assert np.isclose(self.plex.metricGetMaximumMagnitude(), h_max)
+        assert np.isclose(self.plex.metricGetMaximumAnisotropy(), a_max)
+        assert np.isclose(self.plex.metricGetTargetComplexity(), target)
+        assert np.isclose(self.plex.metricGetNormalizationOrder(), p)
+        assert np.isclose(self.plex.metricGetGradationFactor(), beta)
+        assert np.isclose(self.plex.metricGetHausdorffNumber(), hausd)
+
+        metric1 = self.plex.metricCreateUniform(0.5)
+        metric2 = self.plex.metricCreateUniform(1.0)
+        metric = self.plex.metricCreate()
+        det = self.plex.metricDeterminantCreate()
+        self.plex.metricAverage2(metric1, metric2, metric)
+        metric1.array[:] *= 1.5
+        assert np.allclose(metric.array, metric1.array)
+        self.plex.metricIntersection2(metric1, metric2, metric)
+        assert np.allclose(metric.array, metric2.array)
+        self.plex.metricEnforceSPD(metric, metric1, det)
+        assert np.allclose(metric.array, metric1.array)
+        self.plex.metricNormalize(metric, metric1, det, restrictSizes=False, restrictAnisotropy=False)
+        metric2.scale(pow(target, 2.0/self.DIM))
+        assert np.allclose(metric1.array, metric2.array)
 
     def testAdapt(self):
-        dim = self.plex.getDimension()
-        if dim == 1: return
-        vStart, vEnd = self.plex.getDepthStratum(0)
-        numVertices = vEnd-vStart
-        metric_array = np.zeros([numVertices,dim,dim],dtype=PETSc.ScalarType)
-        for met in metric_array:
-            met[:,:] = np.diag([9]*dim)
-        metric = PETSc.Vec().createWithArray(metric_array)
+        if self.DIM == 1: return
+        self.plex.orient()
+        plex = self.plex.refine()
+        plex.distribute()
+        if self.CELLS is None and not plex.isSimplex(): return
+        if sum(self.DOFS) > 1: return
+        metric = plex.metricCreateUniform(9.0)
         try:
-            newplex = self.plex.adaptMetric(metric,"")
+            newplex = plex.adaptMetric(metric,"")
         except PETSc.Error as exc:
-            if exc.ierr != ERR_SUP: raise
+            if exc.ierr != ERR_ARG_OUTOFRANGE: raise
 
 
 # --------------------------------------------------------------------
@@ -357,6 +418,7 @@ class BaseTestPlexHDF5(object):
                 vwr.pushFormat(format=informt)
                 plex.load(viewer=vwr)
                 plex.setOptionsPrefix("loaded_")
+                plex.distributeSetDefault(False)
                 plex.setFromOptions()
                 vwr.popFormat()
                 vwr.destroy()
@@ -374,12 +436,14 @@ class BaseTestPlexHDF5(object):
                 part = plex.getPartitioner()
                 part.setType(self.partitionerType())
                 _ = plex.distribute(overlap=0)
+                plex.setName("DMPlex Object")
                 plex.setOptionsPrefix("redistributed_")
                 plex.setFromOptions()
                 self.outputPlex(plex)
                 # Save redistributed dm to XDMF in parallel
                 vwr.create(self.outfile(), mode='w', comm=comm)
                 vwr.pushFormat(format=self.outformat())
+                plex.setName("DMPlex Object")
                 plex.view(viewer=vwr)
                 vwr.popFormat()
                 vwr.destroy()
