@@ -3,6 +3,7 @@
 from petsc4py import PETSc
 import unittest
 from sys import getrefcount
+import numpy
 
 # --------------------------------------------------------------------
 
@@ -36,6 +37,7 @@ class BaseTestSNES(object):
 
     def tearDown(self):
         self.snes = None
+        PETSc.garbage_cleanup()
 
     def testGetSetType(self):
         self.assertEqual(self.snes.getType(), self.SNES_TYPE)
@@ -120,8 +122,8 @@ class BaseTestSNES(object):
         x, y = r.duplicate(), r.duplicate()
         x[0], x[1] = [1, 2]
         self.snes.computeFunction(x, y)
-        self.assertAlmostEqual(abs(y[0]), 0.0)
-        self.assertAlmostEqual(abs(y[1]), 0.0)
+        self.assertAlmostEqual(abs(y[0]), 0.0, places=5)
+        self.assertAlmostEqual(abs(y[1]), 0.0, places=5)
 
     def testGetSetJac(self):
         A, P, jac = self.snes.getJacobian()
@@ -210,12 +212,19 @@ class BaseTestSNES(object):
         rh, ih = self.snes.getConvergenceHistory()
         self.assertEqual(len(rh), 0)
         self.assertEqual(len(ih), 0)
-        self.assertAlmostEqual(abs(x[0]), 1.0)
-        self.assertAlmostEqual(abs(x[1]), 2.0)
+        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
         # XXX this test should not be here !
         reason = self.snes.callConvergenceTest(1, 0, 0, 0)
         self.assertTrue(reason > 0)
 
+        # test interface
+        x = self.snes.getSolution()
+        x.setArray([2,3])
+        self.snes.solve()
+        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
+
     def testResetAndSolve(self):
         self.snes.reset()
         self.testSolve()
@@ -233,7 +242,7 @@ class BaseTestSNES(object):
         self.testSolve()
         self.assertTrue(len(reshist) > 0)
         reshist = {}
-        self.snes.cancelMonitor()
+        self.snes.monitorCancel()
         self.assertEqual(getrefcount(monitor), refcnt)
         self.testSolve()
         self.assertTrue(len(reshist) == 0)
@@ -317,8 +326,8 @@ class BaseTestSNES(object):
         x.setArray([2,3])
         b.set(0)
         self.snes.solve(b, x)
-        self.assertAlmostEqual(abs(x[0]), 1.0)
-        self.assertAlmostEqual(abs(x[1]), 2.0)
+        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
 
     def testFDColor(self):
         J = PETSc.Mat().create(PETSc.COMM_SELF)
@@ -342,8 +351,8 @@ class BaseTestSNES(object):
         x.setArray([2,3])
         b.set(0)
         self.snes.solve(b, x)
-        self.assertAlmostEqual(abs(x[0]), 1.0)
-        self.assertAlmostEqual(abs(x[1]), 2.0)
+        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
 
 # --------------------------------------------------------------------
 
