@@ -18,6 +18,7 @@ class BaseTestVec(object):
     def tearDown(self):
         self.vec.destroy()
         self.vec = None
+        PETSc.garbage_cleanup()
 
     def testDuplicate(self):
         self.vec.set(1)
@@ -158,6 +159,19 @@ class BaseTestVec(object):
         self.vec.resetArray()
         self.assertAlmostEqual(abs(self.vec.sum()), self.vec.getSize())
 
+    def testLocalVector(self):
+        rank = self.vec.getComm().Get_rank()
+        self.vec.getArray()[:] = rank + 1
+        ln = self.vec.getLocalSize()
+        lvec = self.vec.createLocalVector()
+        self.vec.getLocalVector(lvec)
+        self.assertEqual(abs(lvec.sum()), (rank+1)*ln)
+        self.vec.restoreLocalVector(lvec)
+        self.vec.getLocalVector(lvec,readonly=True)
+        self.assertEqual(abs(lvec.sum()), (rank+1)*ln)
+        self.vec.restoreLocalVector(lvec,readonly=True)
+        lvec.destroy()
+
     def testSetOption(self):
         opt1 = PETSc.Vec.Option.IGNORE_OFF_PROC_ENTRIES
         opt2 = PETSc.Vec.Option.IGNORE_NEGATIVE_INDICES
@@ -269,7 +283,7 @@ class TestVecWithArray(unittest.TestCase):
         v.setSizes((5,None))
         ghosts = [i % v.size for i in range(v.owner_range[1],v.owner_range[1]+3)]
         v.setMPIGhost(ghosts)
-        v.setArray(numpy.array(range(*v.owner_range)))
+        v.setArray(numpy.array(range(*v.owner_range),dtype=PETSc.ScalarType))
         v.ghostUpdate()
         with v.localForm() as loc:
             self.assertTrue((loc[0:v.local_size] == range(*v.owner_range)).all())
